@@ -24,5 +24,5 @@ includeJqueryUI <- function() {
   .Deprecated(
     msg = "Since v0.2.0, there is no need to call includeJqueryUI() before using other shinyjqui functions"
   )
-  jquiHead()
+  jquiDep()
 }
